export type Metadata = any;
export declare class Test {
    readonly name: string;
    readonly line: number;
    readonly values: ReadonlyMap<string, ReadonlyArray<string>>;
    readonly meta: ReadonlyMap<string, ReadonlyArray<Metadata>>;
    constructor(name: string, line: number, values: ReadonlyMap<string, ReadonlyArray<string>>, meta: ReadonlyMap<string, ReadonlyArray<Metadata>>);
    toJSON(): any;
}
