"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Group = void 0;
class Group {
    constructor(name, line, children, tests) {
        this.name = name;
        this.line = line;
        this.children = children;
        this.tests = tests;
    }
    toJSON() {
        return {
            children: this.children,
            line: this.line,
            name: this.name,
            tests: this.tests,
        };
    }
}
exports.Group = Group;
//# sourceMappingURL=group.js.map