import { Test } from './test';
export declare class Group {
    readonly name: string;
    readonly line: number;
    readonly children: ReadonlyArray<Group>;
    readonly tests: ReadonlyArray<Test>;
    constructor(name: string, line: number, children: ReadonlyArray<Group>, tests: ReadonlyArray<Test>);
    toJSON(): any;
}
