import { Group } from './group';
import { Metadata, Test } from './test';
export type State = 'none' | 'heading';
export { Group, Metadata, Test };
export declare class MDGator {
    private readonly md;
    private state;
    parse(text: string): ReadonlyArray<Group>;
    private translate;
    private translateTest;
}
